parser

package
v0.11.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 12, 2026 License: MIT Imports: 24 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrAppMissingTypeApp         = errors.New(`missing required type "App"`)
	ErrAppMissingPageIndex       = errors.New(`missing required page type "PageIndex"`)
	ErrSignatureMissingReq       = errors.New(`missing the *http.Request parameter`)
	ErrSignatureMissingStreamID  = errors.New(`missing the streamID uint64 parameter`)
	ErrSignatureMultiErrRet      = errors.New(`multiple error return values`)
	ErrSignatureUnsupportedInput = errors.New(`unsupported input parameter`)
	// Deprecated: use ErrSignatureUnsupportedInput.
	ErrSignatureUnknownInput     = ErrSignatureUnsupportedInput
	ErrSignatureEvHandMissingSSE = errors.New(
		"event handler must have a *datastar.ServerSentEventGenerator parameter",
	)
	// Deprecated: use ErrSignatureEvHandMissingSSE.
	ErrSignatureSecondArgNotSSE         = ErrSignatureEvHandMissingSSE
	ErrSignatureEvHandReturnMustBeError = errors.New(
		"event handler must return only error",
	)
	ErrSignatureEvHandMissingEvent = errors.New(
		`event handler must have a parameter named "event" of an event type`,
	)
	// Deprecated: use ErrSignatureEvHandMissingEvent.
	ErrSignatureEvHandFirstArgNotEvent     = ErrSignatureEvHandMissingEvent
	ErrSignatureEvHandFirstArgTypeNotEvent = ErrSignatureEvHandMissingEvent
	ErrSignatureGETMissingBody             = errors.New(
		"GET handler must return body templ.Component",
	)
	ErrSignatureGETBodyWrongName = errors.New(
		"GET handler first templ.Component return must be named \"body\"",
	)
	ErrSignatureGETHeadWrongName = errors.New(
		"GET handler second templ.Component return must be named \"head\"",
	)

	ErrAppHeadMustTakeRequest = errors.New(
		"head must accept *http.Request as first parameter",
	)
	ErrAppHeadMustReturnTemplComponent = errors.New(
		"head must return exactly templ.Component",
	)
	ErrAppHeadUnsupportedInput = errors.New("head has unsupported input parameter")

	ErrAppRecoverErrorInvalidSignature = errors.New(
		`"RecoverError" must have signature ` +
			`(error, *datastar.ServerSentEventGenerator) error`)

	ErrPageMissingFieldApp     = errors.New(`page is missing the "App *App" field`)
	ErrPageHasExtraFields      = errors.New(`page struct has unsupported fields`)
	ErrPageMissingGET          = errors.New(`page is missing the GET handler`)
	ErrPageConflictingGETEmbed = errors.New("conflicting GET handlers in embedded")
	ErrPageNameInvalid         = errors.New("page has invalid name")
	ErrPageMissingPathComm     = errors.New("page is missing path comment")
	ErrPageInvalidPathComm     = errors.New("page has invalid path comment")
	ErrPageIndexPathMustBeRoot = errors.New(`PageIndex path must be "/"`)

	ErrUnsupportedMethod = errors.New(
		"unsupported public method on page type; " +
			"use GET, POST*/PUT*/PATCH*/DELETE* (actions), " +
			"On* (event handlers), or StreamOpen/StreamClose (stream hooks)",
	)

	ErrActionNameMissing      = errors.New("action handler must have a name")
	ErrActionNameInvalid      = errors.New("action has invalid name")
	ErrActionMissingPathComm  = errors.New("action handler is missing path comment")
	ErrActionInvalidPathComm  = errors.New("action handler has invalid path comment")
	ErrActionPathNotUnderPage = errors.New("action handler path is not under page path")

	ErrEventCommMissing     = errors.New("event type is missing subject comment")
	ErrEventCommInvalid     = errors.New("event type has invalid subject comment")
	ErrEventSubjectInvalid  = errors.New("event subject is invalid")
	ErrEvHandDuplicate      = errors.New("duplicate event handler for event")
	ErrEvHandDuplicateEmbed = errors.New("duplicate event handler for event in embedded")

	ErrEventFieldUnexported = errors.New("event field must be exported")
	ErrEventFieldMissingTag = errors.New("event field must have json tag")
	ErrEventFieldEmptyTag   = errors.New(
		"event field json tag must have a non-empty name",
	)
	ErrEventFieldDuplicateTag = errors.New("event field has duplicate json tag value")

	ErrPathParamNotStruct       = paramvalidation.ErrPathParamNotStruct
	ErrPathFieldUnexported      = paramvalidation.ErrPathFieldUnexported
	ErrPathFieldMissingTag      = paramvalidation.ErrPathFieldMissingTag
	ErrPathFieldUnsupportedType = paramvalidation.ErrPathFieldUnsupportedType
	ErrPathFieldNotInRoute      = paramvalidation.ErrPathFieldNotInRoute
	ErrPathMissingRouteVar      = paramvalidation.ErrPathMissingRouteVar
	ErrPathFieldDuplicateTag    = paramvalidation.ErrPathFieldDuplicateTag
	ErrPathFieldEmptyTag        = paramvalidation.ErrPathFieldEmptyTag

	ErrQueryParamNotStruct       = paramvalidation.ErrQueryParamNotStruct
	ErrQueryFieldUnexported      = paramvalidation.ErrQueryFieldUnexported
	ErrQueryFieldMissingTag      = paramvalidation.ErrQueryFieldMissingTag
	ErrQueryFieldDuplicateTag    = paramvalidation.ErrQueryFieldDuplicateTag
	ErrQueryFieldEmptyTag        = paramvalidation.ErrQueryFieldEmptyTag
	ErrQueryFieldUnsupportedType = paramvalidation.ErrQueryFieldUnsupportedType
	ErrQueryFieldInvalidTagName  = paramvalidation.ErrQueryFieldInvalidTagName

	ErrQueryReflectSignalNotInSignals = structtag.ErrQueryReflectSignalNotInSignals

	ErrSignalsParamNotStruct    = paramvalidation.ErrSignalsParamNotStruct
	ErrSignalsFieldUnexported   = paramvalidation.ErrSignalsFieldUnexported
	ErrSignalsFieldMissingTag   = paramvalidation.ErrSignalsFieldMissingTag
	ErrSignalsFieldDuplicateTag = paramvalidation.ErrSignalsFieldDuplicateTag
	ErrSignalsFieldEmptyTag     = paramvalidation.ErrSignalsFieldEmptyTag

	ErrFormAndSignals           = errors.New("handler cannot have both \"form\" and \"signals\" parameters")
	ErrFormFieldUnexported      = paramvalidation.ErrFormFieldUnexported
	ErrFormFieldMissingTag      = paramvalidation.ErrFormFieldMissingTag
	ErrFormFieldDuplicateTag    = paramvalidation.ErrFormFieldDuplicateTag
	ErrFormFieldUnsupportedType = paramvalidation.ErrFormFieldUnsupportedType

	ErrDispatchParamNotFunc    = paramvalidation.ErrDispatchParamNotFunc
	ErrDispatchMustReturnError = paramvalidation.ErrDispatchMustReturnError
	ErrDispatchNoParams        = paramvalidation.ErrDispatchNoParams
	ErrDispatchParamNotEvent   = paramvalidation.ErrDispatchParamNotEvent

	ErrSessionNotStruct     = errors.New("session type must be a struct")
	ErrSessionMissingUserID = errors.New(
		"session type must have a UserID string field",
	)
	ErrSessionMissingIssuedAt = errors.New(
		"session type must have an IssuedAt time.Time field",
	)
	ErrSessionParamNotSessionType = errors.New("session parameter type must be Session")
	ErrSessionTokenParamNotString = errors.New(
		"sessionToken parameter must be of type string",
	)
	ErrStreamIDParamNotUint64 = errors.New("streamID parameter must be of type uint64")

	ErrRedirectNotString             = errors.New("redirect must be a string")
	ErrRedirectStatusNotInt          = errors.New("redirectStatus must be an int")
	ErrRedirectStatusWithoutRedirect = errors.New("redirectStatus requires redirect")

	ErrNewSessionNotSessionType = errors.New("newSession must be of type Session")
	ErrCloseSessionNotBool      = errors.New("closeSession must be of type bool")
	ErrNewSessionWithSSE        = errors.New(
		"newSession cannot be used together with sse parameter",
	)
	ErrCloseSessionWithSSE = errors.New(
		"closeSession cannot be used together with sse parameter",
	)

	ErrEnableBgStreamNotBool = errors.New(
		"enableBackgroundStreaming must be of type bool",
	)
	ErrEnableBgStreamNotGET = errors.New(
		"enableBackgroundStreaming can only be used in GET handlers",
	)
	ErrDisableRefreshNotBool = errors.New(
		"disableRefreshAfterHidden must be of type bool",
	)
	ErrDisableRefreshNotGET = errors.New(
		"disableRefreshAfterHidden can only be used in GET handlers",
	)

	ErrSignatureUnsupportedOutput = errors.New(
		"unsupported output return value",
	)
	ErrUnknownReturnName = errors.New(
		"unknown return value name",
	)
	ErrSignatureStreamHookReturnMustBeError = errors.New(
		"stream hook must return only error",
	)
	ErrStreamHookDuplicateEmbed = errors.New(
		"conflicting stream hook in embedded",
	)

	ErrEventSubjectUserNoSession = errors.New(
		"event with SubjectUser requires a Session type",
	)

	ErrEventSubjectAfterPayload = errors.New(
		"subject field must be defined before payload fields",
	)

	ErrEventSubjectDuplicateSignal = errors.New(
		"multiple event subject fields with the same signal tag",
	)

	ErrEventSubjectUserSignal = errors.New(
		"SubjectUser must not have a signal tag",
	)

	ErrEventSubjectSignalInvalid = errors.New(
		"invalid signal tag value",
	)

	WarnEventNoHandler = errors.New("event type has no handler on any page")

	ErrTemplHrefRelative                 = templcheck.ErrHrefRelative
	ErrTemplActionHardcoded              = templcheck.ErrActionHardcoded
	ErrTemplFormAction                   = templcheck.ErrFormAction
	ErrTemplActionWrongPage              = templcheck.ErrActionWrongPage
	ErrTemplActionContext                = templcheck.ErrActionContext
	ErrTemplHrefContext                  = templcheck.ErrHrefContext
	ErrTemplHrefUnverifiable             = templcheck.ErrHrefUnverifiable
	ErrTemplActionUnverifiable           = templcheck.ErrActionUnverifiable
	ErrTemplActionUnverifiableWithPrefix = templcheck.ErrActionUnverifiableWithPrefix
	ErrTemplActionUnverifiableWithSuffix = templcheck.ErrActionUnverifiableWithSuffix
	ErrTemplHrefExternalIsRelative       = templcheck.ErrHrefExternalIsRelative
)

Functions

This section is empty.

Types

type ErrorActionInvalidPathComm

type ErrorActionInvalidPathComm struct {
	Recv       string // e.g. "PageProfile" or "App"
	MethodName string // e.g. "POSTFoo"
}

ErrorActionInvalidPathComm is ErrActionInvalidPathComm with suggestion context.

func (*ErrorActionInvalidPathComm) Error

func (*ErrorActionInvalidPathComm) Unwrap

func (e *ErrorActionInvalidPathComm) Unwrap() error

type ErrorActionMissingPathComm

type ErrorActionMissingPathComm struct {
	PagePath   string // e.g. "/profile/" (empty for App-level actions)
	Recv       string // e.g. "PageProfile" or "App"
	MethodName string // e.g. "POSTFoo"
}

ErrorActionMissingPathComm is ErrActionMissingPathComm with suggestion context.

func (*ErrorActionMissingPathComm) Error

func (*ErrorActionMissingPathComm) Unwrap

func (e *ErrorActionMissingPathComm) Unwrap() error

type ErrorActionPathNotUnderPage

type ErrorActionPathNotUnderPage struct {
	PagePath   string // e.g. "/profile/"
	Recv       string // e.g. "PageProfile"
	MethodName string // e.g. "POSTFoo"
}

ErrorActionPathNotUnderPage is ErrActionPathNotUnderPage with suggestion context.

func (*ErrorActionPathNotUnderPage) Error

func (*ErrorActionPathNotUnderPage) Unwrap

func (e *ErrorActionPathNotUnderPage) Unwrap() error

type ErrorEventCommInvalid

type ErrorEventCommInvalid struct {
	TypeName string // e.g. "EventFoo"
}

ErrorEventCommInvalid is ErrEventCommInvalid with suggestion context.

func (*ErrorEventCommInvalid) Error

func (e *ErrorEventCommInvalid) Error() string

func (*ErrorEventCommInvalid) Unwrap

func (e *ErrorEventCommInvalid) Unwrap() error

type ErrorEventCommMissing

type ErrorEventCommMissing struct {
	TypeName string // e.g. "EventFoo"
}

ErrorEventCommMissing is ErrEventCommMissing with suggestion context.

func (*ErrorEventCommMissing) Error

func (e *ErrorEventCommMissing) Error() string

func (*ErrorEventCommMissing) Unwrap

func (e *ErrorEventCommMissing) Unwrap() error

type ErrorEventFieldDuplicateTag

type ErrorEventFieldDuplicateTag struct {
	FieldName string // e.g. "UserID"
	TagValue  string // e.g. "user_id"
	TypeName  string // e.g. "EventFoo"
}

ErrorEventFieldDuplicateTag is ErrEventFieldDuplicateTag with suggestion context.

func (*ErrorEventFieldDuplicateTag) Error

func (*ErrorEventFieldDuplicateTag) Unwrap

func (e *ErrorEventFieldDuplicateTag) Unwrap() error

type ErrorEventFieldEmptyTag

type ErrorEventFieldEmptyTag struct {
	FieldName string // e.g. "UserID"
	TypeName  string // e.g. "EventFoo"
}

ErrorEventFieldEmptyTag is ErrEventFieldEmptyTag with suggestion context.

func (*ErrorEventFieldEmptyTag) Error

func (e *ErrorEventFieldEmptyTag) Error() string

func (*ErrorEventFieldEmptyTag) Unwrap

func (e *ErrorEventFieldEmptyTag) Unwrap() error

type ErrorEventFieldMissingTag

type ErrorEventFieldMissingTag struct {
	FieldName string // e.g. "UserID"
	TypeName  string // e.g. "EventFoo"
}

ErrorEventFieldMissingTag is ErrEventFieldMissingTag with suggestion context.

func (*ErrorEventFieldMissingTag) Error

func (e *ErrorEventFieldMissingTag) Error() string

func (*ErrorEventFieldMissingTag) Unwrap

func (e *ErrorEventFieldMissingTag) Unwrap() error

type ErrorEventSubjectAfterPayload

type ErrorEventSubjectAfterPayload struct {
	FieldName string // e.g. "SubjectUser"
	TypeName  string // e.g. "EventFoo"
}

ErrorEventSubjectAfterPayload is ErrEventSubjectAfterPayload with suggestion context.

func (*ErrorEventSubjectAfterPayload) Error

func (*ErrorEventSubjectAfterPayload) Unwrap

type ErrorEventSubjectDuplicateSignal

type ErrorEventSubjectDuplicateSignal struct {
	FieldName      string // e.g. "SubjectFoo" (second occurrence)
	FirstFieldName string // e.g. "SubjectBar" (first occurrence)
	SignalName     string // e.g. "instance_id"
	TypeName       string // e.g. "EventCalcUpdated"
}

ErrorEventSubjectDuplicateSignal is ErrEventSubjectDuplicateSignal with suggestion context.

func (*ErrorEventSubjectDuplicateSignal) Error

func (*ErrorEventSubjectDuplicateSignal) Unwrap

type ErrorEventSubjectSignalInvalid

type ErrorEventSubjectSignalInvalid struct {
	FieldName  string // e.g. "SubjectInstance"
	SignalName string // the invalid tag value
	TypeName   string // e.g. "EventCalc"
}

ErrorEventSubjectSignalInvalid is ErrEventSubjectSignalInvalid with suggestion context.

func (*ErrorEventSubjectSignalInvalid) Error

func (*ErrorEventSubjectSignalInvalid) Unwrap

type ErrorEventSubjectUserNoSession

type ErrorEventSubjectUserNoSession struct {
	TypeName string // e.g. "EventFoo"
	PkgName  string // e.g. "app"
}

ErrorEventSubjectUserNoSession is ErrEventSubjectUserNoSession with suggestion context.

func (*ErrorEventSubjectUserNoSession) Error

func (*ErrorEventSubjectUserNoSession) Unwrap

type ErrorEventSubjectUserSignal

type ErrorEventSubjectUserSignal struct {
	TypeName string // e.g. "EventChat"
}

ErrorEventSubjectUserSignal is ErrEventSubjectUserSignal with suggestion context.

func (*ErrorEventSubjectUserSignal) Error

func (*ErrorEventSubjectUserSignal) Unwrap

func (e *ErrorEventSubjectUserSignal) Unwrap() error

type ErrorFormAndSignals

type ErrorFormAndSignals struct {
	Recv       string
	MethodName string
}

ErrorFormAndSignals is ErrFormAndSignals with context.

func (*ErrorFormAndSignals) Error

func (e *ErrorFormAndSignals) Error() string

func (*ErrorFormAndSignals) Unwrap

func (e *ErrorFormAndSignals) Unwrap() error

type ErrorPageIndexPathMustBeRoot

type ErrorPageIndexPathMustBeRoot struct {
	Route string // the invalid route, e.g. "/home"
}

ErrorPageIndexPathMustBeRoot is ErrPageIndexPathMustBeRoot with suggestion context.

func (*ErrorPageIndexPathMustBeRoot) Error

func (*ErrorPageIndexPathMustBeRoot) Unwrap

func (e *ErrorPageIndexPathMustBeRoot) Unwrap() error

type ErrorPageInvalidPathComm

type ErrorPageInvalidPathComm struct {
	TypeName string // e.g. "PageProfile"
}

ErrorPageInvalidPathComm is ErrPageInvalidPathComm with suggestion context.

func (*ErrorPageInvalidPathComm) Error

func (e *ErrorPageInvalidPathComm) Error() string

func (*ErrorPageInvalidPathComm) Unwrap

func (e *ErrorPageInvalidPathComm) Unwrap() error

type ErrorPageMissingFieldApp

type ErrorPageMissingFieldApp struct {
	TypeName string // e.g. "PageProfile"
}

ErrorPageMissingFieldApp is ErrPageMissingFieldApp with suggestion context.

func (*ErrorPageMissingFieldApp) Error

func (e *ErrorPageMissingFieldApp) Error() string

func (*ErrorPageMissingFieldApp) Unwrap

func (e *ErrorPageMissingFieldApp) Unwrap() error

type ErrorPageMissingGET

type ErrorPageMissingGET struct {
	TypeName string // e.g. "PageProfile"
}

ErrorPageMissingGET is ErrPageMissingGET with suggestion context.

func (*ErrorPageMissingGET) Error

func (e *ErrorPageMissingGET) Error() string

func (*ErrorPageMissingGET) Unwrap

func (e *ErrorPageMissingGET) Unwrap() error

type ErrorPageMissingPathComm

type ErrorPageMissingPathComm struct {
	TypeName string // e.g. "PageProfile"
}

ErrorPageMissingPathComm is ErrPageMissingPathComm with suggestion context.

func (*ErrorPageMissingPathComm) Error

func (e *ErrorPageMissingPathComm) Error() string

func (*ErrorPageMissingPathComm) Unwrap

func (e *ErrorPageMissingPathComm) Unwrap() error

type ErrorSignatureUnsupportedInput

type ErrorSignatureUnsupportedInput struct {
	ParamName  string // e.g. "b"
	ParamType  string // e.g. "*http.Request"
	Recv       string // e.g. "PageFoo"
	MethodName string // e.g. "GET"
	// ExpectedName is set when there is exactly one candidate for the
	// parameter (e.g. type is Session but name is not "session").
	ExpectedName string
	// CandidateNames lists multiple possible parameter names when the
	// parameter type matches more than one known input slot.
	CandidateNames []string
}

ErrorSignatureUnsupportedInput is ErrSignatureUnsupportedInput with context.

func (*ErrorSignatureUnsupportedInput) Error

func (*ErrorSignatureUnsupportedInput) Unwrap

type ErrorTemplActionContext

type ErrorTemplActionContext = templcheck.ErrorActionContext

Type aliases for templ-check error types defined in the templcheck subpackage.

type ErrorTemplActionHardcoded

type ErrorTemplActionHardcoded = templcheck.ErrorActionHardcoded

Type aliases for templ-check error types defined in the templcheck subpackage.

type ErrorTemplActionUnverifiable

type ErrorTemplActionUnverifiable = templcheck.ErrorActionUnverifiable

Type aliases for templ-check error types defined in the templcheck subpackage.

type ErrorTemplActionUnverifiableWithPrefix

type ErrorTemplActionUnverifiableWithPrefix = templcheck.ErrorActionUnverifiableWithPrefix

Type aliases for templ-check error types defined in the templcheck subpackage.

type ErrorTemplActionUnverifiableWithSuffix

type ErrorTemplActionUnverifiableWithSuffix = templcheck.ErrorActionUnverifiableWithSuffix

Type aliases for templ-check error types defined in the templcheck subpackage.

type ErrorTemplActionWrongPage

type ErrorTemplActionWrongPage = templcheck.ErrorActionWrongPage

Type aliases for templ-check error types defined in the templcheck subpackage.

type ErrorTemplFormAction

type ErrorTemplFormAction = templcheck.ErrorFormAction

Type aliases for templ-check error types defined in the templcheck subpackage.

type ErrorTemplHrefContext

type ErrorTemplHrefContext = templcheck.ErrorHrefContext

Type aliases for templ-check error types defined in the templcheck subpackage.

type ErrorTemplHrefExternalIsRelative

type ErrorTemplHrefExternalIsRelative = templcheck.ErrorHrefExternalIsRelative

Type aliases for templ-check error types defined in the templcheck subpackage.

type ErrorTemplHrefRelative

type ErrorTemplHrefRelative = templcheck.ErrorHrefRelative

Type aliases for templ-check error types defined in the templcheck subpackage.

type ErrorTemplHrefUnverifiable

type ErrorTemplHrefUnverifiable = templcheck.ErrorHrefUnverifiable

Type aliases for templ-check error types defined in the templcheck subpackage.

type ErrorUnknownReturnName

type ErrorUnknownReturnName struct {
	Name       string // e.g. "content"
	Recv       string // e.g. "PageFoo"
	MethodName string // e.g. "GET"
	Suggestion string // e.g. "body" (closest match, may be empty)
}

ErrorUnknownReturnName is ErrUnknownReturnName with context.

func (*ErrorUnknownReturnName) Error

func (e *ErrorUnknownReturnName) Error() string

func (*ErrorUnknownReturnName) Unwrap

func (e *ErrorUnknownReturnName) Unwrap() error

type Errors

type Errors struct {
	// contains filtered or unexported fields
}

func Parse

func Parse(appPackagePath string) (app *model.App, errs Errors)

func (*Errors) All

func (e *Errors) All() iter.Seq2[int, error]

func (*Errors) Entry

func (e *Errors) Entry(i int) (token.Position, error)

func (*Errors) Err

func (e *Errors) Err(err error)

func (*Errors) ErrAt

func (e *Errors) ErrAt(pos token.Position, err error)

func (*Errors) Error

func (e *Errors) Error() string

func (*Errors) Len

func (e *Errors) Len() int

func (*Errors) WarnAt

func (e *Errors) WarnAt(pos token.Position, err error)

func (*Errors) Warning

func (e *Errors) Warning(i int) (token.Position, error)

func (*Errors) WarningsLen

func (e *Errors) WarningsLen() int

type WarningEventNoHandler

type WarningEventNoHandler struct {
	TypeName string
}

func (*WarningEventNoHandler) Error

func (w *WarningEventNoHandler) Error() string

func (*WarningEventNoHandler) Unwrap

func (w *WarningEventNoHandler) Unwrap() error

Directories

Path Synopsis
Package errsuggest provides fix suggestions for parser errors.
Package errsuggest provides fix suggestions for parser errors.
internal
methodkind
Package methodkind classifies handler method names into HTTP method kinds (GET, POST, PUT, PATCH, DELETE) or event handlers.
Package methodkind classifies handler method names into HTTP method kinds (GET, POST, PUT, PATCH, DELETE) or event handlers.
paramvalidation
Package paramvalidation validates handler parameter structs (path, query, signals) and route-to-path consistency.
Package paramvalidation validates handler parameter structs (path, query, signals) and route-to-path consistency.
structinspect
Package structinspect provides AST helpers for inspecting Go struct types and method receivers.
Package structinspect provides AST helpers for inspecting Go struct types and method receivers.
structtag
Package structtag provides struct tag value extraction and cross-validation for Datapages handler parameters.
Package structtag provides struct tag value extraction and cross-validation for Datapages handler parameters.
templcheck
Package templcheck validates .templ files for common mistakes:
Package templcheck validates .templ files for common mistakes:
typecheck
Package typecheck provides type-checking predicates for common Go types used in Datapages handler signatures.
Package typecheck provides type-checking predicates for common Go types used in Datapages handler signatures.
urlpath
Package urlpath provides shared URL path utilities.
Package urlpath provides shared URL path utilities.

Jump to